#include <DHT.h>
#include <OneWire.h> 
#include <DallasTemperature.h> 
#include <ESP8266WiFi.h>

// Sensoren
#define DHTPIN 2 // GPIO Port DHT
#define DHTTYPE DHT22
#define ONE_WIRE_BUS 0 // GPIO Port DS18b20

float temperature_ds1;
float temperature_ds2;
DHT dht(DHTPIN, DHTTYPE);

OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature sensors(&oneWire);
DeviceAddress Probe01 = { 0x28, 0xFF, 0x5D, 0x84, 0x03, 0x15, 0x02, 0xAD}; // Hardwareadresse DS18b20_1
DeviceAddress Probe02 = { 0x28, 0xFF, 0xB3, 0xAB, 0x03, 0x15, 0x02, 0x3F}; // Hardwareadresse DS18b20_2

// WLAN
const char* ssid = ""; // WLAN-SSID
const char* password = ""; // WLAN-Passwort
WiFiClient client;

// Thingspeak
const char* host = "api.thingspeak.com"; //
String writeAPIKey = "";

// Allgemein
int messintervall = 60; // Messintervall in Sekunden

void setup() {
  // Sensoren
  dht.begin();
  sensors.begin();
  sensors.setResolution(Probe01, 12);
  sensors.setResolution(Probe02, 12);

  delay(1000);

  // WLAN
  WiFi.begin(ssid, password);

  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
  }
}

void loop() {
  // Temp DS18b20
  sensors.requestTemperatures(); 
  temperature_ds1 = sensors.getTempC(Probe01);
  temperature_ds2 = sensors.getTempC(Probe02);

  // Temp und Feuchtigkeit DHT22
  float humidity = dht.readHumidity(); //Feuchtigkeit
  float temperature = dht.readTemperature(); // Temperatur
  
  if (isnan(humidity) || isnan(temperature)) {
    return;
  }

 
  if (client.connect(host,80)) { // wenn Verbindungsaufbau zu Thingspeak erfolgreich
    
    // Aufbereitung der Daten für die Übermittlung
    String url = writeAPIKey;
    url +="&field1=";
    url += String(temperature);// Temperatur (DHT)
    url +="&field2=";
    url += String(humidity);// Feuchtigkeit (DHT)
    url +="&field3=";
    url += String(temperature_ds1);
    url +="&field4=";
    url += String(temperature_ds2);
    url += "\r\n\r\n";

    // Übermittlung der Daten an Thingspeak
    client.print("POST /update HTTP/1.1\n");
    client.print("Host: api.thingspeak.com\n");
    client.print("Connection: close\n");
    client.print("X-THINGSPEAKAPIKEY: "+writeAPIKey+"\n");
    client.print("Content-Type: application/x-www-form-urlencoded\n");
    client.print("Content-Length: ");
    client.print(url.length());
    client.print("\n\n");
    client.print(url);
  }
  else // wenn Verbindungsaufbau zu Thingspeak fehlschlägt
  {
    ESP.restart(); // Neustart ESP8266
  }
  client.stop();
  delay(messintervall*1000); // Pause bis die Schleife erneut ausgeführt wird
}

